.. _dcsc api:

:py:mod:`icclim.dcsc`
=====================

.. py:module:: icclim.dcsc

.. autoapi-nested-parse::

   Direction de la Climatologie et des Services Climatiques (DCSC) indices.

   Meteo France's Direction de la Climatologie et des Services Climatiques (DCSC)
   specialized indices.

   The DCSC indices public API, via the `icclim.dcsc` package, is generated from the
   `icclim.dcsc.registry.DcscIndexRegistry` registry definitions.
   The parameters  of the functions are specialized to each index but are all taken from
   `icclim.main.index` general function.
   In other words, the DCSC indices in `icclim.dcsc` module are specializations of
   `icclim.main.index` for DCSC indices.



Submodules
----------
.. toctree::
   :titlesonly:
   :maxdepth: 1

   registry/index.rst


Package Contents
----------------

.. automodule:: icclim._generated._dcsc
   :members:

   .. autosummary::
    :nosignatures:

    .. Documentation below is auto-generated with the extract-icclim-funs.py script
    .. Generated API comment:Begin
    tav
    txav
    trav
    tx10
    tx90
    tn10
    tn90
    tnfd
    txfd
    sd
    tx35
    tr
    txnd
    tnht
    tnnd
    tncwd
    txhwd
    hdd
    cdd
    pav
    pint
    rr
    rr1mm
    pn20mm
    pxcdd
    pxcwd
    r99
    pfl90
    pq90
    pq99
    ffav
    ff98

.. Generated API comment:End
